jmxtrans

package
v0.0.0-...-c7d5118 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 30, 2026 License: Apache-2.0 Imports: 20 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetJMXMetrics

func GetJMXMetrics(service discovery.Service) []config.JmxMetric

GetJMXMetrics parses the jmx info and returns a list of JmxMetric struct.

Types

type JMX

type JMX struct {
	Pusher                  types.PointPusher
	OutputConfigurationFile string
	// ContactAddress is the address where jmxtrans can reach Glouton.
	// If this is an IP address, Glouton will only listen on this address.
	// If this is an hostname, Glouton will listen on 0.0.0.0 and use this hostname
	// in jmxtrans configuration
	// The default is "127.0.0.1".
	ContactAddress string
	// ContactPort is the preferred port to bind to.
	ContactPort                   int
	OutputConfigurationPermission os.FileMode
	// contains filtered or unexported fields
}

JMX allow to gather metrics from JVM using JMX It use jmxtrans to achieve this goal.

func (*JMX) Run

func (j *JMX) Run(ctx context.Context) error

Run configure jmxtrans to send metrics to a local graphite server.

func (*JMX) UpdateConfig

func (j *JMX) UpdateConfig(services []discovery.Service, metricResolution time.Duration) error

UpdateConfig update the jmxtrans configuration.

Jump to