Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type JMX ¶
type JMX struct {
Pusher types.PointPusher
OutputConfigurationFile string
// ContactAddress is the address where jmxtrans can reach Glouton.
// If this is an IP address, Glouton will only listen on this address.
// If this is an hostname, Glouton will listen on 0.0.0.0 and use this hostname
// in jmxtrans configuration
// The default is "127.0.0.1".
ContactAddress string
// ContactPort is the preferred port to bind to.
ContactPort int
OutputConfigurationPermission os.FileMode
// contains filtered or unexported fields
}
JMX allow to gather metrics from JVM using JMX It use jmxtrans to achieve this goal.
Click to show internal directories.
Click to hide internal directories.